@@ -3,23 +3,22 @@ from __future__ import annotations
 import functools
 import re
 from contextlib import suppress
-from itertools import chain
 from typing import TYPE_CHECKING
 from typing import Any
 from typing import Callable
-from typing import Sequence
+from typing import Literal
 from typing import Sized
 from typing import TypeVar
 
 import pandas as pd
 
 from narwhals._compliant.series import EagerSeriesNamespace
-from narwhals.dtypes import _DelayedCategories
 from narwhals.exceptions import ColumnNotFoundError
 from narwhals.exceptions import DuplicateError
 from narwhals.exceptions import ShapeError
 from narwhals.utils import Implementation
 from narwhals.utils import Version
+from narwhals.utils import _DeferredIterable
 from narwhals.utils import isinstance_or_issubclass
 
 T = TypeVar("T", bound=Sized)
@@ -27,7 +26,6 @@ T = TypeVar("T", bound=Sized)
 if TYPE_CHECKING:
     from pandas._typing import Dtype as PandasDtype
 
-    from narwhals._pandas_like.dataframe import PandasLikeDataFrame
     from narwhals._pandas_like.expr import PandasLikeExpr
     from narwhals._pandas_like.series import PandasLikeSeries
     from narwhals.dtypes import DType
@@ -89,6 +87,8 @@ PA_DURATION_RGX = r"""^
 $"""
 PATTERN_PA_DURATION = re.compile(PA_DURATION_RGX, re.VERBOSE)
 
+UNIT_DICT = {"d": "D", "m": "min"}
+
 
 def align_and_extract_native(
     lhs: PandasLikeSeries, rhs: PandasLikeSeries | object
@@ -166,36 +166,6 @@ def set_index(
     return obj.set_axis(index, axis=0, **kwargs)  # type: ignore[attr-defined]
 
 
-def set_columns(
-    obj: T,
-    columns: list[str],
-    *,
-    implementation: Implementation,
-    backend_version: tuple[int, ...],
-) -> T:
-    """Wrapper around pandas' set_axis to set object columns.
-
-    We can set `copy` / `inplace` based on implementation/version.
-    """
-    if implementation is Implementation.CUDF:  # pragma: no cover
-        obj = obj.copy(deep=False)  # type: ignore[attr-defined]
-        obj.columns = columns  # type: ignore[attr-defined]
-        return obj
-    if implementation is Implementation.PANDAS and (
-        backend_version < (1,)
-    ):  # pragma: no cover
-        kwargs = {"inplace": False}
-    else:
-        kwargs = {}
-    if implementation is Implementation.PANDAS and (
-        (1, 5) <= backend_version < (3,)
-    ):  # pragma: no cover
-        kwargs["copy"] = False
-    else:  # pragma: no cover
-        pass
-    return obj.set_axis(columns, axis=1, **kwargs)  # type: ignore[attr-defined]
-
-
 def rename(
     obj: T,
     *args: Any,
@@ -212,7 +182,7 @@ def rename(
 
 
 @functools.lru_cache(maxsize=16)
-def non_object_native_to_narwhals_dtype(native_dtype: Any, version: Version) -> DType:
+def non_object_native_to_narwhals_dtype(native_dtype: Any, version: Version) -> DType:  # noqa: C901, PLR0912
     dtype = str(native_dtype)
 
     dtypes = version.dtypes
@@ -255,9 +225,7 @@ def non_object_native_to_narwhals_dtype(native_dtype: Any, version: Version) ->
     if dtype.startswith("dictionary<"):
         return dtypes.Categorical()
     if dtype == "category":
-        return native_categorical_to_narwhals_dtype(
-            native_dtype, version, lambda: tuple(native_dtype.categories)
-        )
+        return native_categorical_to_narwhals_dtype(native_dtype, version)
     if (match_ := PATTERN_PD_DATETIME.match(dtype)) or (
         match_ := PATTERN_PA_DATETIME.match(dtype)
     ):
@@ -305,20 +273,33 @@ def object_native_to_narwhals_dtype(
 def native_categorical_to_narwhals_dtype(
     native_dtype: pd.CategoricalDtype,
     version: Version,
-    get_categories: Callable[[], tuple[str, ...]],
+    implementation: Literal[Implementation.CUDF] | None = None,
 ) -> DType:
     dtypes = version.dtypes
     if version is Version.V1:
         return dtypes.Categorical()
     if native_dtype.ordered:
-        return dtypes.Enum(_DelayedCategories(get_categories))
+        into_iter = (
+            _cudf_categorical_to_list(native_dtype)
+            if implementation is Implementation.CUDF
+            else native_dtype.categories.to_list
+        )
+        return dtypes.Enum(_DeferredIterable(into_iter))
     return dtypes.Categorical()
 
 
-def native_to_narwhals_dtype(
+def _cudf_categorical_to_list(
     native_dtype: Any,
-    version: Version,
-    implementation: Implementation,
+) -> Callable[[], list[Any]]:  # pragma: no cover
+    # NOTE: https://docs.rapids.ai/api/cudf/stable/user_guide/api_docs/api/cudf.core.dtypes.categoricaldtype/#cudf.core.dtypes.CategoricalDtype
+    def fn() -> list[Any]:
+        return native_dtype.categories.to_arrow().to_pylist()
+
+    return fn
+
+
+def native_to_narwhals_dtype(
+    native_dtype: Any, version: Version, implementation: Implementation
 ) -> DType:
     str_dtype = str(native_dtype)
 
@@ -333,8 +314,9 @@ def native_to_narwhals_dtype(
         return arrow_native_to_narwhals_dtype(native_dtype.pyarrow_dtype, version)
     if str_dtype == "category" and implementation.is_cudf():
         # https://github.com/rapidsai/cudf/issues/18536
+        # https://github.com/rapidsai/cudf/issues/14027
         return native_categorical_to_narwhals_dtype(
-            native_dtype, version, lambda: tuple(native_dtype.categories.to_pandas())
+            native_dtype, version, Implementation.CUDF
         )
     if str_dtype != "object":
         return non_object_native_to_narwhals_dtype(native_dtype, version)
@@ -372,7 +354,7 @@ def is_pyarrow_dtype_backend(dtype: Any, implementation: Implementation) -> bool
     return get_dtype_backend(dtype, implementation) == "pyarrow"
 
 
-def narwhals_to_native_dtype(  # noqa: PLR0915
+def narwhals_to_native_dtype(  # noqa: C901, PLR0912, PLR0915
     dtype: DType | type[DType],
     dtype_backend: DTypeBackend,
     implementation: Implementation,
@@ -494,7 +476,7 @@ def narwhals_to_native_dtype(  # noqa: PLR0915
         try:
             import pyarrow as pa  # ignore-banned-import
         except ModuleNotFoundError:  # pragma: no cover
-            msg = "PyArrow>=11.0.0 is required for `Date` dtype."
+            msg = "'pyarrow>=11.0.0' is required for `Date` dtype."
         return "date32[pyarrow]"
     if isinstance_or_issubclass(dtype, dtypes.Enum):
         if version is Version.V1:
@@ -583,7 +565,7 @@ def int_dtype_mapper(dtype: Any) -> str:
     return "int64"
 
 
-def calculate_timestamp_datetime(
+def calculate_timestamp_datetime(  # noqa: C901, PLR0912
     s: pd.Series[int], original_time_unit: str, time_unit: str
 ) -> pd.Series[int]:
     if original_time_unit == "ns":
@@ -666,32 +648,6 @@ def select_columns_by_name(
         ) from e
 
 
-def pivot_table(
-    df: PandasLikeDataFrame,
-    values: Sequence[str],
-    index: Sequence[str],
-    columns: Sequence[str],
-    aggregate_function: str | None,
-) -> Any:
-    categorical = df._version.dtypes.Categorical
-    kwds: dict[Any, Any] = {"observed": True}
-    if df._implementation is Implementation.CUDF:
-        kwds.pop("observed")
-        cols = set(chain(values, index, columns))
-        schema = df.schema.items()
-        if any(tp for name, tp in schema if name in cols and isinstance(tp, categorical)):
-            msg = "`pivot` with Categoricals is not implemented for cuDF backend"
-            raise NotImplementedError(msg)
-    return df.native.pivot_table(
-        values=values,
-        index=index,
-        columns=columns,
-        aggfunc=aggregate_function,
-        margins=False,
-        **kwds,
-    )
-
-
 def check_column_names_are_unique(columns: pd.Index[str]) -> None:
     try:
         len_unique_columns = len(columns.drop_duplicates())
