@@ -13,7 +13,11 @@ data = {
 
 
 def test_with_row_index(constructor: Constructor, request: pytest.FixtureRequest) -> None:
-    if ("pyspark" in str(constructor)) or "duckdb" in str(constructor):
+    if (
+        ("pyspark" in str(constructor))
+        or "duckdb" in str(constructor)
+        or "ibis" in str(constructor)
+    ):
         request.applymarker(pytest.mark.xfail)
     result = nw.from_native(constructor(data)).with_row_index()
     expected = {"index": [0, 1], "a": ["foo", "bars"], "ab": ["foo", "bars"]}
